@@ -1,4 +1,4 @@
-#! /usr/bin/env python3
+#! /usr/bin/env python
 """From http://stackoverflow.com/a/12260597/400691"""
 import sys
 
@@ -29,9 +29,6 @@ settings.configure(
     AUTH_USER_MODEL = 'tests.User',
     ROOT_URLCONF='user_management.api.tests.urls',
     REST_FRAMEWORK={
-        'DEFAULT_PERMISSION_CLASSES': (
-            'rest_framework.permissions.IsAuthenticated',
-        ),
         'DEFAULT_AUTHENTICATION_CLASSES': (
             'rest_framework.authentication.TokenAuthentication',
             'rest_framework.authentication.SessionAuthentication',
